Crate comprehensive_http

Crate comprehensive_http 

comprehensive Resource types for HTTP server.

This crate provides Resource types for use in a comprehensive Assembly. To use it, build an Assembly and include resources from this crate in the dependency graph.

HTTP (and HTTPS) Server

One or more HTTP servers can be run by including a Resource of type HttpServer<FooServer> where FooServer has derived HttpServingInstance. See the server module docs.

Diagnostics Instance

The diag module implements a HttpServingInstance specifically intended to serve content for diagnostics and other internal functions like metrics serving. The idea is that the endpoint for this server is not exposed to end users.

Re-exports

pub use server::HttpServer;
pub use server::HttpServingInstance;

Modules

diag
HTTP server meant to serve diagnostics for a comprehensive server.
server
comprehensive Resource types for HTTP serving

Derive Macros

HttpServingInstance